if [ -x usr/bin/scrollkeeper-update ]; then
  usr/bin/scrollkeeper-update -p var/lib/scrollkeeper 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi
( cd usr/lib ; rm -rf libtotem-plparser.so.1 )
( cd usr/lib ; ln -sf libtotem-plparser.so.1.1.4 libtotem-plparser.so.1 )
( cd usr/lib ; rm -rf libtotem-plparser.so )
( cd usr/lib ; ln -sf libtotem-plparser.so.1.1.4 libtotem-plparser.so )
